@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2021 The strace developers.
+ * Copyright (c) 1999-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -22,11 +22,12 @@ SYS_FUNC(io_setup)
 {
 	if (entering(tcp)) {
 		/* nr_events */
+		tprints_arg_name("nr_events");
 		unsigned int nr_events = tcp->u_arg[0];
 		PRINT_VAL_U(nr_events);
-		tprint_arg_next();
 	} else {
 		/* ctx_idp */
+		tprints_arg_next_name("ctx_idp");
 		printnum_ptr(tcp, tcp->u_arg[1]);
 	}
 	return 0;
@@ -35,6 +36,7 @@ SYS_FUNC(io_setup)
 SYS_FUNC(io_destroy)
 {
 	/* ctx_id */
+	tprints_arg_name("ctx_id");
 	printaddr(tcp->u_arg[0]);
 
 	return RVAL_DECODED;
@@ -160,8 +162,8 @@ print_iocb(struct tcb *tcp, const struct iocb *cb)
 			tprints_field_name("aio_buf");
 			tprint_iov(tcp, cb->aio_nbytes, cb->aio_buf,
 				   cb->aio_lio_opcode == 8
-				   ? IOV_DECODE_STR
-				   : IOV_DECODE_ADDR);
+				   ? iov_decode_str
+				   : iov_decode_addr);
 		} else {
 			tprint_struct_next();
 			PRINT_FIELD_X(*cb, aio_buf);
@@ -208,16 +210,17 @@ SYS_FUNC(io_submit)
 	kernel_ulong_t iocbp;
 
 	/* ctx_id */
+	tprints_arg_name("ctx_id");
 	printaddr(tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* nr */
+	tprints_arg_next_name("nr");
 	const kernel_long_t nr =
 		truncate_klong_to_current_wordsize(tcp->u_arg[1]);
 	PRINT_VAL_D(nr);
-	tprint_arg_next();
 
 	/* iocbpp */
+	tprints_arg_next_name("iocbpp");
 	if (nr < 0)
 		printaddr(addr);
 	else
@@ -249,19 +252,20 @@ SYS_FUNC(io_cancel)
 {
 	if (entering(tcp)) {
 		/* ctx_id */
+		tprints_arg_name("ctx_id");
 		printaddr(tcp->u_arg[0]);
-		tprint_arg_next();
 
 		/* iocb */
+		tprints_arg_next_name("iocb");
 		struct iocb cb;
 		if (!umove_or_printaddr(tcp, tcp->u_arg[1], &cb)) {
 			tprint_struct_begin();
 			print_iocb_header(tcp, &cb);
 			tprint_struct_end();
 		}
-		tprint_arg_next();
 	} else {
 		/* result */
+		tprints_arg_next_name("result");
 		struct io_event event;
 		if (!umove_or_printaddr(tcp, tcp->u_arg[2], &event))
 			print_io_event(tcp, &event, sizeof(event), 0);
@@ -277,24 +281,24 @@ print_io_getevents(struct tcb *const tcp, const print_obj_by_addr_fn print_ts,
 		kernel_long_t nr;
 
 		/* ctx_id */
+		tprints_arg_name("ctx_id");
 		printaddr(tcp->u_arg[0]);
-		tprint_arg_next();
 
 		/* min_nr */
+		tprints_arg_next_name("min_nr");
 		nr = truncate_klong_to_current_wordsize(tcp->u_arg[1]);
 		PRINT_VAL_D(nr);
-		tprint_arg_next();
 
 		/* nr */
+		tprints_arg_next_name("nr");
 		nr = truncate_klong_to_current_wordsize(tcp->u_arg[2]);
 		PRINT_VAL_D(nr);
-		tprint_arg_next();
 	} else {
 		/* events */
+		tprints_arg_next_name("events");
 		struct io_event buf;
 		print_array(tcp, tcp->u_arg[3], tcp->u_rval, &buf, sizeof(buf),
 			    tfetch_mem, print_io_event, 0);
-		tprint_arg_next();
 
 		/*
 		 * Since the timeout and sig parameters are read by the kernel
@@ -304,12 +308,12 @@ print_io_getevents(struct tcb *const tcp, const print_obj_by_addr_fn print_ts,
 		temporarily_clear_syserror(tcp);
 
 		/* timeout */
+		tprints_arg_next_name("timeout");
 		print_ts(tcp, tcp->u_arg[4]);
 
 		if (has_sig) {
-			tprint_arg_next();
-
 			/* sig */
+			tprints_arg_next_name("sig");
 			print_kernel_sigset(tcp, tcp->u_arg[5]);
 		}
 
