@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2021 The strace developers.
+ * Copyright (c) 1999-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -15,8 +15,12 @@
 
 SYS_FUNC(delete_module)
 {
+	/* name */
+	tprints_arg_name("name");
 	printstr(tcp, tcp->u_arg[0]);
-	tprints(", ");
+
+	/* flags */
+	tprints_arg_next_name("flags");
 	printflags(delete_module_flags, tcp->u_arg[1], "O_???");
 
 	return RVAL_DECODED;
@@ -24,8 +28,16 @@ SYS_FUNC(delete_module)
 
 SYS_FUNC(init_module)
 {
+	/* module_image */
+	tprints_arg_name("module_image");
 	printaddr(tcp->u_arg[0]);
-	tprintf(", %" PRI_klu ", ", tcp->u_arg[1]);
+
+	/* len */
+	tprints_arg_next_name("len");
+	PRINT_VAL_U(tcp->u_arg[1]);
+
+	/* param_values */
+	tprints_arg_next_name("param_values");
 	printstr(tcp, tcp->u_arg[2]);
 
 	return RVAL_DECODED;
@@ -35,13 +47,16 @@ SYS_FUNC(init_module)
 
 SYS_FUNC(finit_module)
 {
-	/* file descriptor */
+	/* fd */
+	tprints_arg_name("fd");
 	printfd(tcp, tcp->u_arg[0]);
-	tprints(", ");
+
 	/* param_values */
+	tprints_arg_next_name("param_values");
 	printstr(tcp, tcp->u_arg[1]);
-	tprints(", ");
+
 	/* flags */
+	tprints_arg_next_name("flags");
 	printflags(module_init_flags, tcp->u_arg[2], "MODULE_INIT_???");
 
 	return RVAL_DECODED;
