@@ -4,7 +4,7 @@
  * Copyright (c) 2010 Carmelo Amoroso <carmelo.amoroso@st.com>
  * Copyright (c) 2015 Ezequiel Garcia <ezequiel@vanguardiasur.com.ar>
  * Copyright (c) 2014-2015 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2014-2021 The strace developers.
+ * Copyright (c) 2014-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -23,18 +23,19 @@
 SYS_FUNC(cacheflush)
 {
 	/* addr */
+	tprints_arg_name("addr");
 	printaddr(tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* scope */
+	tprints_arg_next_name("scope");
 	printxval(cacheflush_scope, tcp->u_arg[1], "FLUSH_SCOPE_???");
-	tprint_arg_next();
 
 	/* flags */
+	tprints_arg_next_name("flags");
 	printflags(cacheflush_flags, tcp->u_arg[2], "FLUSH_CACHE_???");
-	tprint_arg_next();
 
 	/* len */
+	tprints_arg_next_name("len");
 	PRINT_VAL_U(tcp->u_arg[3]);
 
 	return RVAL_DECODED;
@@ -47,14 +48,15 @@ SYS_FUNC(cacheflush)
 SYS_FUNC(cacheflush)
 {
 	/* start addr */
+	tprints_arg_name("addr");
 	printaddr(tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* length */
+	tprints_arg_next_name("length");
 	PRINT_VAL_U(tcp->u_arg[1]);
-	tprint_arg_next();
 
 	/* flags */
+	tprints_arg_next_name("flags");
 	printxval(cacheflush_flags, tcp->u_arg[2], "?CACHE");
 
 	return RVAL_DECODED;
@@ -67,14 +69,15 @@ SYS_FUNC(cacheflush)
 SYS_FUNC(cacheflush)
 {
 	/* addr */
+	tprints_arg_name("addr");
 	printaddr(tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* len */
+	tprints_arg_next_name("len");
 	PRINT_VAL_U(tcp->u_arg[1]);
-	tprint_arg_next();
 
 	/* flags */
+	tprints_arg_next_name("flags");
 	printflags(cacheflush_flags, tcp->u_arg[2], "CACHEFLUSH_???");
 
 	return RVAL_DECODED;
@@ -85,10 +88,11 @@ SYS_FUNC(cacheflush)
 SYS_FUNC(cacheflush)
 {
 	/* addr */
+	tprints_arg_name("addr");
 	printaddr(tcp->u_arg[0]);
-	tprint_arg_next();
 
 	/* len */
+	tprints_arg_next_name("len");
 	PRINT_VAL_U(tcp->u_arg[3]);
 
 	/* scope and flags (cache type) are currently ignored */
