@@ -83,12 +83,10 @@ extern char *stpcpy(char *dst, const char *src);
  * linux/<ARCH>/syscallent*.h:
  *	all have nargs <= 6 except mips o32 which has nargs <= 7.
  */
-# ifndef MAX_ARGS
-#  ifdef LINUX_MIPSO32
-#   define MAX_ARGS	7
-#  else
-#   define MAX_ARGS	6
-#  endif
+# ifdef LINUX_MIPSO32
+#  define MAX_ARGS	7
+# else
+#  define MAX_ARGS	6
 # endif
 /* default sorting method for call profiling */
 # ifndef DEFAULT_SORTBY
@@ -404,7 +402,7 @@ struct tcb {
 
 extern const struct_sysent stub_sysent;
 # define tcp_sysent(tcp) (tcp->s_ent ?: &stub_sysent)
-# define n_args(tcp) (tcp_sysent(tcp)->nargs)
+# define n_args(tcp) MIN(tcp_sysent(tcp)->nargs, MAX_ARGS)
 
 # include "xlat.h"
 
@@ -417,6 +415,7 @@ extern const struct xlat dirent_types[];
 extern const struct xlat ethernet_protocols[];
 extern const struct xlat evdev_abs[];
 extern const struct xlat evdev_ev[];
+extern const struct xlat fs_xflags[];
 extern const struct xlat fsmagic[];
 extern const struct xlat futexbitset[];
 extern const struct xlat iffflags[];
@@ -520,6 +519,7 @@ extern bool Tflag;
 extern int Tflag_scale;
 extern int Tflag_width;
 extern bool iflag;
+extern bool Nflag;
 extern bool count_wallclock;
 extern bool tracing_fds;
 extern long long syscall_limit;
@@ -1020,8 +1020,6 @@ extern void print_xlat_ex(uint64_t val, const char *str, uint32_t style);
 	print_xlat_ex((val_), #val_, XLAT_STYLE_FMT_D)
 
 extern int printargs(struct tcb *);
-extern int printargs_u(struct tcb *);
-extern int printargs_d(struct tcb *);
 
 extern int printflags_ex(uint64_t flags, const char *dflt,
 			 enum xlat_style, const struct xlat *, ...)
@@ -1099,7 +1097,7 @@ typedef void (*print_obj_by_addr_size_fn)(struct tcb *,
  * @param opaque_data      A value that is unconditionally passed to print_func
  *                         in the opaque_data argument.
  * @param flags            Combination of xlat style settings and additional
- *                         flags from enum print_array_flags that are appled
+ *                         flags from enum print_array_flags that are applied
  *                         to index printing.
  * @param index_xlat       xlat that is used for printing indices.
  * @param index_dflt       Default string for the values not found
