@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 The strace developers.
+ * Copyright (c) 2014-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -11,14 +11,15 @@ SYS_FUNC(getcpu)
 {
 	if (exiting(tcp)) {
 		/* cpu */
+		tprints_arg_name("cpu");
 		printnum_int(tcp, tcp->u_arg[0], "%u");
-		tprint_arg_next();
 
 		/* node */
+		tprints_arg_next_name("node");
 		printnum_int(tcp, tcp->u_arg[1], "%u");
-		tprint_arg_next();
 
 		/* tcache */
+		tprints_arg_next_name("tcache");
 		printaddr(tcp->u_arg[2]);
 	}
 	return 0;
