@@ -9,9 +9,7 @@
 static int
 arch_get_syscall_args(struct tcb *tcp)
 {
-	unsigned int i;
-
-	for (i = 0; i < n_args(tcp); ++i)
+	for (unsigned int i = 0; i < n_args(tcp); ++i)
 		if (upeek(tcp, (5 + i) * 4, &tcp->u_arg[i]) < 0)
 			return -1;
 	return 1;
