@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2016-2021 The strace developers.
+ * Copyright (c) 2016-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -24,11 +24,7 @@
 #include "xlat/rtnl_route_attrs.h"
 #include "xlat/rtnl_rta_metrics_attrs.h"
 
-bool
-decode_nla_rt_class(struct tcb *const tcp,
-		    const kernel_ulong_t addr,
-		    const unsigned int len,
-		    const void *const opaque_data)
+DECL_NLA(rt_class)
 {
 	uint32_t num;
 
@@ -39,11 +35,7 @@ decode_nla_rt_class(struct tcb *const tcp,
 	return true;
 }
 
-bool
-decode_nla_rt_proto(struct tcb *const tcp,
-		    const kernel_ulong_t addr,
-		    const unsigned int len,
-		    const void *const opaque_data)
+DECL_NLA(rt_proto)
 {
 	uint8_t num;
 
@@ -188,11 +180,7 @@ decode_rtvia(struct tcb *const tcp,
 	return true;
 }
 
-static bool
-decode_rta_encap_type(struct tcb *const tcp,
-		      const kernel_ulong_t addr,
-		      const unsigned int len,
-		      const void *const opaque_data)
+DECL_NLA(lwt_encap_type)
 {
 	uint16_t type;
 
@@ -225,7 +213,7 @@ static const nla_decoder_t rtmsg_nla_decoders[] = {
 	[RTA_VIA]		= decode_rtvia,
 	[RTA_NEWDST]		= decode_route_addr,
 	[RTA_PREF]		= decode_nla_u8,
-	[RTA_ENCAP_TYPE]	= decode_rta_encap_type,
+	[RTA_ENCAP_TYPE]	= decode_nla_lwt_encap_type,
 	[RTA_ENCAP]		= NULL, /* unimplemented */
 	[RTA_EXPIRES]		= decode_nla_u64,
 	[RTA_PAD]		= NULL,
@@ -233,20 +221,47 @@ static const nla_decoder_t rtmsg_nla_decoders[] = {
 	[RTA_TTL_PROPAGATE]	= decode_nla_u8,
 	[RTA_IP_PROTO]		= decode_nla_u8,
 	[RTA_SPORT]		= decode_nla_u16,
-	[RTA_DPORT]		= decode_nla_u16
+	[RTA_DPORT]		= decode_nla_u16,
+	[RTA_NH_ID]		= decode_nla_u32,
+	[RTA_FLOWLABEL]		= decode_nla_be32,
 };
 
+/*
+ * RTA_MULTIPATH payload is a list of struct rtnexthop-headed RTA_* netlink
+ * attributes:
+ *
+ * {RTA_MULTIPATH nlattr hdr} [ [{struct rtnexthop}, {RTA_* nlattr}],
+ *                              [{struct rtnexthop}, {RTA_* nlattr}], ... ]
+ */
 static bool
 decode_rta_multipath(struct tcb *const tcp,
 		     const kernel_ulong_t addr,
 		     const unsigned int len,
 		     const void *const opaque_data)
 {
+	bool is_array = false;
 	struct rtnexthop nh;
+	kernel_ulong_t cur = addr;
+	kernel_ulong_t left = len;
 
 	if (len < sizeof(nh))
 		return false;
-	else if (!umove_or_printaddr(tcp, addr, &nh)) {
+
+	while (!umove_or_printaddr(tcp, cur, &nh)) {
+		static const size_t offset = RTNH_ALIGN(sizeof(nh));
+		const unsigned int rtnh_len = MIN(left, nh.rtnh_len);
+
+		if (cur == addr && nh.rtnh_len < len) {
+			tprint_array_begin();
+			is_array = true;
+		}
+
+		if (cur > addr)
+			tprint_array_next();
+
+		if (rtnh_len > offset)
+			tprint_array_begin();
+
 		/* print the whole structure regardless of its rtnh_len */
 		tprint_struct_begin();
 		PRINT_FIELD_U(nh, rtnh_len);
@@ -259,18 +274,28 @@ decode_rta_multipath(struct tcb *const tcp,
 		PRINT_FIELD_IFINDEX(nh, rtnh_ifindex);
 		tprint_struct_end();
 
-		const unsigned short rtnh_len = MIN(len, nh.rtnh_len);
-		const size_t offset = RTNH_ALIGN(sizeof(nh));
 		if (rtnh_len > offset) {
 			tprint_array_next();
-			decode_nlattr(tcp, addr + offset, rtnh_len - offset,
+			decode_nlattr(tcp, cur + offset, rtnh_len - offset,
 				      rtnl_route_attrs, "RTA_???",
 				      rtmsg_nla_decoders,
 				      ARRAY_SIZE(rtmsg_nla_decoders),
 				      opaque_data);
 		}
+
+		if (rtnh_len > offset)
+			tprint_array_end();
+
+		if (RTNH_ALIGN(rtnh_len) >= left)
+			break;
+
+		cur += RTNH_ALIGN(rtnh_len);
+		left -= RTNH_ALIGN(rtnh_len);
 	}
 
+	if (is_array)
+		tprint_array_end();
+
 	return true;
 }
 
