@@ -55,7 +55,10 @@ typedef struct {
 	uint32_t stx_atomic_write_segments_max; /* Max atomic write segment count */
 	uint32_t stx_dio_read_offset_align; /* File offset alignment for direct I/O reads */
 
-	uint64_t reserved2[9]; /* Spare space for future expansion */
+	uint32_t stx_atomic_write_unit_max_opt; /* Optimised max atomic write unit in bytes */
+
+	uint32_t reserved2[1];
+	uint64_t reserved3[8]; /* Spare space for future expansion */
 } struct_statx;
 
 #endif /* !STRACE_STATX_H */
