@@ -1,7 +1,8 @@
 /*
  * Wrappers for recvmmsg and sendmmsg syscalls.
  *
- * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@strace.io>
+ * Copyright (c) 2016-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,7 +10,7 @@
 
 #include "tests.h"
 #include <errno.h>
-#include <asm/unistd.h>
+#include "scno.h"
 
 #ifndef __NR_recvmmsg
 # define __NR_recvmmsg -1
@@ -24,7 +25,7 @@
 int
 recv_mmsg(const int fd, struct mmsghdr *const vec,
 	  const unsigned int vlen, const unsigned int flags,
-	  struct timespec *const timeout)
+	  kernel_old_timespec_t *const timeout)
 {
 	int rc = socketcall(__NR_recvmmsg, SC_recvmmsg,
 			    fd, (long) vec, vlen, flags, (long) timeout);
