@@ -139,7 +139,7 @@ print_uint(const unsigned int *p, size_t i)
 	else
 		printf("[%s", sk_meminfo_strs[i]);
 
-	printf("] = %u", *p);
+	printf("]=%u", *p);
 }
 
 static const struct {
@@ -535,7 +535,9 @@ main(void)
 		{ ENUM_KNOWN(0x36, TLS_CIPHER_CHACHA20_POLY1305) },
 		{ ENUM_KNOWN(0x37, TLS_CIPHER_SM4_GCM) },
 		{ ENUM_KNOWN(0x38, TLS_CIPHER_SM4_CCM) },
-		{ ARG_XLAT_UNKNOWN(0x39, "TLS_CIPHER_???") },
+		{ ENUM_KNOWN(0x39, TLS_CIPHER_ARIA_GCM_128) },
+		{ ENUM_KNOWN(0x3a, TLS_CIPHER_ARIA_GCM_256) },
+		{ ARG_XLAT_UNKNOWN(0x3b, "TLS_CIPHER_???") },
 		{ ARG_XLAT_UNKNOWN(0xcafe, "TLS_CIPHER_???") },
 	};
 
