@@ -2,7 +2,7 @@
  * Check bpf syscall decoding.
  *
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2015-2024 The strace developers.
+ * Copyright (c) 2015-2025 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -918,13 +918,13 @@ static const struct bpf_attr_check BPF_PROG_ATTACH_checks[] = {
 			.target_fd = -1,
 			.attach_bpf_fd = -2,
 			.attach_type = 2,
-			.attach_flags = 0xdfc0,
+			.attach_flags = 0xdf80,
 			.replace_bpf_fd = -3,
 		} },
 		.size = offsetofend(struct BPF_PROG_ATTACH_struct, replace_bpf_fd),
 		.str = "target_fd=-1, attach_bpf_fd=-2"
 		       ", attach_type=BPF_CGROUP_INET_SOCK_CREATE"
-		       ", attach_flags=0xdfc0 /* BPF_F_??? */"
+		       ", attach_flags=0xdf80 /* BPF_F_??? */"
 		       ", replace_bpf_fd=-3"
 	},
 };
@@ -1198,7 +1198,7 @@ print_BPF_PROG_QUERY_attr4(const struct bpf_attr_check *check,
 	       ", attach_type=0xfeedface /* BPF_??? */"
 	       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
 	       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE"
-	       "|BPF_F_BEFORE|BPF_F_AFTER|BPF_F_ID|0xbeefcac0"
+	       "|BPF_F_BEFORE|BPF_F_AFTER|BPF_F_ID|BPF_F_PREORDER|0xbeefca80"
 #if defined(INJECT_RETVAL)
 	       ", prog_ids=[0, 1, 4294967295, 2718281828], prog_cnt=4}"
 #else
@@ -1228,7 +1228,7 @@ print_BPF_PROG_QUERY_attr5(const struct bpf_attr_check *check,
 	       ", attach_type=0xfeedface /* BPF_??? */"
 	       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
 	       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE"
-	       "|BPF_F_BEFORE|BPF_F_AFTER|BPF_F_ID|0xbeefcac0"
+	       "|BPF_F_BEFORE|BPF_F_AFTER|BPF_F_ID|BPF_F_PREORDER|0xbeefca80"
 #if defined(INJECT_RETVAL)
 	       ", prog_ids=[0, 1, 4294967295, 2718281828, ... /* %p */]"
 	       ", prog_cnt=5}",
@@ -1266,7 +1266,7 @@ static struct bpf_attr_check BPF_PROG_QUERY_checks[] = {
 			.target_fd = 3141592653U,
 			.attach_type = 58,
 			.query_flags = 0xfffffffe,
-			.attach_flags = 0xffffdfc0,
+			.attach_flags = 0xffffdf80,
 			.prog_ids = 0xffffffffffffffffULL,
 			.prog_cnt = 2718281828,
 		} },
@@ -1274,7 +1274,7 @@ static struct bpf_attr_check BPF_PROG_QUERY_checks[] = {
 		.str = "query={target_fd=-1153374643"
 		       ", attach_type=0x3a /* BPF_??? */"
 		       ", query_flags=0xfffffffe /* BPF_F_QUERY_??? */"
-		       ", attach_flags=0xffffdfc0 /* BPF_F_??? */"
+		       ", attach_flags=0xffffdf80 /* BPF_F_??? */"
 		       ", prog_ids="
 		       BIG_ADDR("0xffffffffffffffff", "0xffffffff")
 		       ", prog_cnt=2718281828}",
@@ -1284,7 +1284,7 @@ static struct bpf_attr_check BPF_PROG_QUERY_checks[] = {
 			.target_fd = 3141592653U,
 			.attach_type = 0xfeedface,
 			.query_flags = 0xdeadf00d,
-			.attach_flags = 0xbeef203f,
+			.attach_flags = 0xbeef207f,
 			.prog_ids = 0xffffffffffffffffULL,
 			.prog_cnt = 0,
 		} },
@@ -1294,7 +1294,7 @@ static struct bpf_attr_check BPF_PROG_QUERY_checks[] = {
 		       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
 		       ", attach_flags=BPF_F_ALLOW_OVERRIDE|BPF_F_ALLOW_MULTI"
 		       "|BPF_F_REPLACE|BPF_F_BEFORE|BPF_F_AFTER|BPF_F_ID"
-		       "|BPF_F_LINK|0xbeef0000"
+		       "|BPF_F_PREORDER|BPF_F_LINK|0xbeef0000"
 		       ", prog_ids=" BIG_ADDR_MAYBE("0xffffffffffffffff") "[]"
 		       ", prog_cnt=0}",
 	},
