@@ -1,7 +1,7 @@
 /*
  * Check GPIO_* ioctl decoding.
  *
- * Copyright (c) 2021 The strace developers.
+ * Copyright (c) 2021-2024 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -71,7 +71,7 @@ do_ioctl(kernel_ulong_t cmd, kernel_ulong_t arg)
 	return rc;
 }
 
-static inline long
+static long
 do_ioctl_ptr(kernel_ulong_t cmd, const void *arg)
 {
 	return do_ioctl(cmd, (uintptr_t) arg);
@@ -161,7 +161,7 @@ test_print_gpioline_info_unwatch(void)
 	printf("ioctl(-1, %s, NULL) = %s\n",
 	       XLAT_STR(GPIO_GET_LINEINFO_UNWATCH_IOCTL), errstr);
 
-	TAIL_ALLOC_OBJECT_VAR_PTR(uint32_t, p_offset);
+	TAIL_ALLOC_OBJECT_CONST_PTR(uint32_t, p_offset);
 
 	*p_offset = 0;
 	do_ioctl_ptr(GPIO_GET_LINEINFO_UNWATCH_IOCTL, p_offset);
@@ -506,7 +506,7 @@ test_print_gpio_v2_line_request(void)
 
 	rc = do_ioctl_ptr(GPIO_V2_GET_LINE_IOCTL, p_line_request);
 	printf("ioctl(-1, %s, {num_lines=4, offsets=[18, 35, 52, 69], "
-	       "config={flags=0, num_attrs=0}, consumer=\"line consumer\"}",
+	       "consumer=\"line consumer\", config={flags=0, num_attrs=0}}",
 	       XLAT_STR(GPIO_V2_GET_LINE_IOCTL));
 	if (rc >= 0)
 		printf(" => {fd=100}");
@@ -516,7 +516,7 @@ test_print_gpio_v2_line_request(void)
 	p_line_request->event_buffer_size = 0xdeafdace;
 	rc = do_ioctl_ptr(GPIO_V2_GET_LINE_IOCTL, p_line_request);
 	printf("ioctl(-1, %s, {num_lines=4, offsets=[18, 35, 52, 69], "
-	       "config={flags=0, num_attrs=0}, consumer=\"line consumer\", "
+	       "consumer=\"line consumer\", config={flags=0, num_attrs=0}, "
 	       "event_buffer_size=3736066766}",
 	       XLAT_STR(GPIO_V2_GET_LINE_IOCTL));
 	if (rc >= 0)
@@ -528,7 +528,7 @@ test_print_gpio_v2_line_request(void)
 	p_line_request->padding[1] = 0xfeedface;
 	rc = do_ioctl_ptr(GPIO_V2_GET_LINE_IOCTL, p_line_request);
 	printf("ioctl(-1, %s, {num_lines=4, offsets=[18, 35, 52, 69], "
-	       "config={flags=0, num_attrs=0}, consumer=\"line consumer\", "
+	       "consumer=\"line consumer\", config={flags=0, num_attrs=0}, "
 	       "padding=[0, 0xfeedface, 0, 0, 0]}",
 	       XLAT_STR(GPIO_V2_GET_LINE_IOCTL));
 	if (rc >= 0)
@@ -542,7 +542,7 @@ test_print_gpio_v2_line_request(void)
 		p_line_request->offsets[i] = i + 1;
 	rc = do_ioctl_ptr(GPIO_V2_GET_LINE_IOCTL, p_line_request);
 	printf("ioctl(-1, %s, {num_lines=65, offsets=" str_line_seq
-	       ", config={flags=0, num_attrs=0}, consumer=\"line consumer\"}",
+	       ", consumer=\"line consumer\", config={flags=0, num_attrs=0}}",
 	       XLAT_STR(GPIO_V2_GET_LINE_IOCTL));
 	if (rc >= 0)
 		printf(" => {fd=100}");
