@@ -1,7 +1,7 @@
 /*
  * Check decoding of sched_getparam and sched_setparam syscalls.
  *
- * Copyright (c) 2016-2021 The strace developers.
+ * Copyright (c) 2016-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -34,9 +34,9 @@ main(void)
 	param->sched_priority = -1;
 	rc = syscall(__NR_sched_setparam, pid, param);
 	pidns_print_leader();
-	printf("sched_setparam(%d%s, [%d]) = %ld %s (%m)\n",
+	printf("sched_setparam(%d%s, [%d]) = %s\n",
 	       pid, pid_str,
-	       param->sched_priority, rc, errno2name());
+	       param->sched_priority, sprintrc(rc));
 
 	pidns_print_leader();
 	puts("+++ exited with 0 +++");
