@@ -1,7 +1,7 @@
 /*
  * Check decoding of tkill syscall.
  *
- * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@strace.io>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,6 +9,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_tkill
 
@@ -33,22 +34,30 @@ k_tkill(const unsigned int tid, const unsigned int sig)
 int
 main(void)
 {
-	const int pid = getpid();
+	PIDNS_TEST_INIT;
+
+	const int tid = syscall(__NR_gettid);
+	const char *tid_str = pidns_pid2str(PT_TID);
 	const int bad_pid = -1;
 	const int bad_sig = 0xface;
 
-	k_tkill(pid, 0);
-	printf("tkill(%d, 0) = %s\n", pid, errstr);
+	k_tkill(tid, 0);
+	pidns_print_leader();
+	printf("tkill(%d%s, 0) = %s\n", tid, tid_str, errstr);
 
-	k_tkill(pid, SIGCONT);
-	printf("tkill(%d, SIGCONT) = %s\n", pid, errstr);
+	k_tkill(tid, SIGCONT);
+	pidns_print_leader();
+	printf("tkill(%d%s, SIGCONT) = %s\n", tid, tid_str, errstr);
 
 	k_tkill(bad_pid, bad_sig);
+	pidns_print_leader();
 	printf("tkill(%d, %d) = %s\n", bad_pid, bad_sig, errstr);
 
 	k_tkill(bad_pid, -bad_sig);
+	pidns_print_leader();
 	printf("tkill(%d, %d) = %s\n", bad_pid, -bad_sig, errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
