@@ -2,7 +2,7 @@
  * Check decoding of copy_file_range syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2016-2021 The strace developers.
+ * Copyright (c) 2016-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -28,10 +28,9 @@ main(void)
 
 	long rc = syscall(__NR_copy_file_range,
 			  fd_in, off_in, fd_out, off_out, len, flags);
-	printf("copy_file_range(%d, [%lld], %d, [%lld], %zu, %u)"
-	       " = %ld %s (%m)\n",
+	printf("copy_file_range(%d, [%lld], %d, [%lld], %zu, %u) = %s\n",
 	       (int) fd_in, *off_in, (int) fd_out, *off_out, len, flags,
-	       rc, errno2name());
+	       sprintrc(rc));
 
 	puts("+++ exited with 0 +++");
 	return 0;
