@@ -2,7 +2,7 @@
  * Check decoding of getrandom syscall.
  *
  * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2015-2021 The strace developers.
+ * Copyright (c) 2015-2023 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -39,8 +39,8 @@ main(void)
 
 	if (syscall(__NR_getrandom, buf, sizeof(buf), 0x3003) != -1)
 		perror_msg_and_skip("getrandom");
-	printf("getrandom(%p, 4, GRND_NONBLOCK|GRND_RANDOM|0x3000) = "
-	       "-1 EINVAL (%m)\n", buf);
+	printf("getrandom(%p, 4, GRND_NONBLOCK|GRND_RANDOM|0x3000)"
+	       RVAL_EINVAL, buf);
 
 	puts("+++ exited with 0 +++");
 	return 0;
