@@ -1,31 +1,11 @@
 /*
  * Check decoding of MCAST_JOIN_GROUP/MCAST_LEAVE_GROUP.
  *
- * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@strace.io>
+ * Copyright (c) 2017-2025 The strace developers.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
@@ -40,8 +20,8 @@
 # include <sys/socket.h>
 # include <arpa/inet.h>
 
-#define	multi4addr	"224.0.0.3"
-#define	multi6addr	"ff01::c"
+# define multi4addr	"224.0.0.3"
+# define multi6addr	"ff01::c"
 
 static const char *errstr;
 
@@ -59,17 +39,24 @@ main(void)
 {
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct group_req, greq4);
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct group_req, greq6);
-	unsigned int i;
 
 	greq6->gr_interface = greq4->gr_interface = ifindex_lo();
 	if (!greq4->gr_interface)
 		perror_msg_and_skip("lo");
 
 	greq4->gr_group.ss_family = AF_INET;
-	inet_pton(AF_INET, multi4addr, &greq4->gr_group.ss_family + 2);
+	union {
+		struct sockaddr_in *s;
+		typeof(greq4->gr_group) *g;
+	} ug4 = { .g = &greq4->gr_group };
+	inet_pton(AF_INET, multi4addr, &ug4.s->sin_addr);
 
 	greq6->gr_group.ss_family = AF_INET6;
-	inet_pton(AF_INET6, multi6addr, &greq6->gr_group.ss_family + 4);
+	union {
+		struct sockaddr_in6 *s;
+		typeof(greq6->gr_group) *g;
+	} ug6 = { .g = &greq6->gr_group };
+	inet_pton(AF_INET6, multi6addr, &ug6.s->sin6_addr);
 
 	(void) close(0);
 	if (socket(AF_INET, SOCK_DGRAM, 0))
@@ -96,20 +83,20 @@ main(void)
 		{
 			ARG_STR(SOL_IPV6), ARG_STR(MCAST_JOIN_GROUP), greq6,
 			"gr_group={sa_family=AF_INET6, sin6_port=htons(65535)"
-			", inet_pton(AF_INET6, \"" multi6addr "\", &sin6_addr)"
 			", sin6_flowinfo=htonl(4294967295)"
+			", inet_pton(AF_INET6, \"" multi6addr "\", &sin6_addr)"
 			", sin6_scope_id=4294967295}"
 		},
 		{
 			ARG_STR(SOL_IPV6), ARG_STR(MCAST_LEAVE_GROUP), greq6,
 			"gr_group={sa_family=AF_INET6, sin6_port=htons(65535)"
-			", inet_pton(AF_INET6, \"" multi6addr "\", &sin6_addr)"
 			", sin6_flowinfo=htonl(4294967295)"
+			", inet_pton(AF_INET6, \"" multi6addr "\", &sin6_addr)"
 			", sin6_scope_id=4294967295}"
 		}
 	};
 
-	for (i = 0; i < ARRAY_SIZE(opts); ++i) {
+	for (unsigned int i = 0; i < ARRAY_SIZE(opts); ++i) {
 		/* optlen < 0, EINVAL */
 		set_opt(0, opts[i].level, opts[i].name, opts[i].val, -1U);
 		printf("setsockopt(0, %s, %s, %p, -1) = %s\n",
